Youkai Apartment no Yuuga na Nichijou - Japanese subtitles - AJATT
Author: Tatsumoto Ren
Description: Japanese subtitles for Japanese anime, dramas, TV shows, and movies
Keywords: japanese, subtitles, anime, TV, dramas, AJATT

# Youkai Apartment no Yuuga na Nichijou

Subtitle format: All SRT ASS
wget

    wget --no-glob --no-clobber --content-disposition --trust-server-names --iri 'https://raw.githubusercontent.com/Ajatt-Tools/kitsunekko-mirror/refs/heads/main/subtitles/unsorted/Youkai%20Apartment%20no%20Yuuga%20na%20Nichijou/Elegant%20Yokai%20Apartment%20Life.S01E01.JA.srt' 'https://raw.githubusercontent.com/Ajatt-Tools/kitsunekko-mirror/refs/heads/main/subtitles/unsorted/Youkai%20Apartment%20no%20Yuuga%20na%20Nichijou/Elegant%20Yokai%20Apartment%20Life.S01E02.JA.srt' 'https://raw.githubusercontent.com/Ajatt-Tools/kitsunekko-mirror/refs/heads/main/subtitles/unsorted/Youkai%20Apartment%20no%20Yuuga%20na%20Nichijou/Elegant%20Yokai%20Apartment%20Life.S01E03.JA.srt'

# | Name | Size | Last modified
--- | --- | --- | ---
1 | Elegant Yokai Apartment Life.S01E01.JA.srt | 25.68 KiB | 22 Aug 2024 17:40:34
2 | Elegant Yokai Apartment Life.S01E02.JA.srt | 28.36 KiB | 22 Aug 2024 17:40:34
3 | Elegant Yokai Apartment Life.S01E03.JA.srt | 26.78 KiB | 22 Aug 2024 17:40:34

Nothing to show.

wget

    wget --no-glob --no-clobber --content-disposition --trust-server-names --iri 'https://raw.githubusercontent.com/Ajatt-Tools/kitsunekko-mirror/refs/heads/main/subtitles/unsorted/Youkai%20Apartment%20no%20Yuuga%20na%20Nichijou/Elegant%20Yokai%20Apartment%20Life.S01E01.JA.srt' 'https://raw.githubusercontent.com/Ajatt-Tools/kitsunekko-mirror/refs/heads/main/subtitles/unsorted/Youkai%20Apartment%20no%20Yuuga%20na%20Nichijou/Elegant%20Yokai%20Apartment%20Life.S01E02.JA.srt' 'https://raw.githubusercontent.com/Ajatt-Tools/kitsunekko-mirror/refs/heads/main/subtitles/unsorted/Youkai%20Apartment%20no%20Yuuga%20na%20Nichijou/Elegant%20Yokai%20Apartment%20Life.S01E03.JA.srt'

# | Name | Size | Last modified
--- | --- | --- | ---
1 | Elegant Yokai Apartment Life.S01E01.JA.srt | 25.68 KiB | 22 Aug 2024 17:40:34
2 | Elegant Yokai Apartment Life.S01E02.JA.srt | 28.36 KiB | 22 Aug 2024 17:40:34
3 | Elegant Yokai Apartment Life.S01E03.JA.srt | 26.78 KiB | 22 Aug 2024 17:40:34

Upload new files — Search MAL — Back to Index